==> haskell-store-core-0.4.4.1-2-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-store-core.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 store-core
version:              0.4.4.1
visibility:           public
id:                   store-core-0.4.4.1-9othBuizlFrGUnZxJ9TZi
key:                  store-core-0.4.4.1-9othBuizlFrGUnZxJ9TZi
license:              MIT
copyright:            2016 FP Complete
maintainer:           Michael Sloan <sloan@fpcomplete.com>
homepage:             https://github.com/fpco/store#readme
synopsis:             Fast and lightweight binary serialization
category:             Serialization, Data
abi:                  719e8fb4ca08a69a954211f846d78cfd
exposed:              True
exposed-modules:      Data.Store.Core
hidden-modules:       Paths_store_core
import-dirs:          /usr/lib/ghc-8.8.1/site-local/store-core-0.4.4.1
library-dirs:         /usr/lib/ghc-8.8.1/site-local/store-core-0.4.4.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.8.1/store-core-0.4.4.1
hs-libraries:         HSstore-core-0.4.4.1-9othBuizlFrGUnZxJ9TZi
depends:
    base-4.13.0.0 bytestring-0.10.9.0 ghc-prim-0.5.3
    primitive-0.7.0.0-BJKNB1CdxR09IS7Mq0RtDA text-1.2.4.0
    transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-store-core/html/store-core.haddock
haddock-html:         /usr/share/doc/haskell-store-core/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-store-core-0.4.4.2-1-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-store-core.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 store-core
version:              0.4.4.2
visibility:           public
id:                   store-core-0.4.4.2-BQ2Lufpk2CbJZJiRLjseGf
key:                  store-core-0.4.4.2-BQ2Lufpk2CbJZJiRLjseGf
license:              MIT
copyright:            2016 FP Complete
maintainer:           Michael Sloan <sloan@fpcomplete.com>
homepage:             https://github.com/fpco/store#readme
synopsis:             Fast and lightweight binary serialization
category:             Serialization, Data
abi:                  35ffa9145618bd627e8ed70b2b995102
exposed:              True
exposed-modules:      Data.Store.Core
hidden-modules:       Paths_store_core
import-dirs:          /usr/lib/ghc-8.8.1/site-local/store-core-0.4.4.2
library-dirs:         /usr/lib/ghc-8.8.1/site-local/store-core-0.4.4.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.8.1/store-core-0.4.4.2
hs-libraries:         HSstore-core-0.4.4.2-BQ2Lufpk2CbJZJiRLjseGf
depends:
    base-4.13.0.0 bytestring-0.10.9.0 ghc-prim-0.5.3
    primitive-0.7.0.0-BJKNB1CdxR09IS7Mq0RtDA text-1.2.4.0
    transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-store-core/html/store-core.haddock
haddock-html:         /usr/share/doc/haskell-store-core/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
